@@ -17,6 +17,7 @@ class ServiceForOrder(int, Enum):
     LMK = 4
     PROF = 3
     CERT = 1
+    OUT = 6
 
 
 class PaySystem(str, Enum):
@@ -74,6 +75,12 @@ class CovidFields(BaseModel):
         use_enum_values = True
 
 
+class OutData(BaseModel):
+    address: str
+    lat: Optional[Decimal]
+    long: Optional[Decimal]
+
+
 class LabExtraFields(BaseModel):
     gender: Optional[Gender]
     nationality: Optional[str]
@@ -96,6 +103,7 @@ class LabExtraFields(BaseModel):
     work_place_phone: Optional[str]
     work_place_address: Optional[str]
     trip: Optional[str]
+    out: Optional[OutData]
 
     class Config:
         use_enum_values = True
